@@ -1,7 +1,7 @@
 """Time Dependant Variational Principle (TDVP) with MPS (finite version only).
 
-The TDVP MPS algorithm was first proposed by [Haegeman2011]_. However the stability of the
-algorithm was later improved in [Haegeman2016]_, that we are following in this implementation.
+The TDVP MPS algorithm was first proposed by :cite:`haegeman2011`. However the stability of the
+algorithm was later improved in :cite:`haegeman2016`, that we are following in this implementation.
 The general idea of the algorithm is to project the quantum time evolution in the manyfold of MPS
 with a given bond dimension. Compared to e.g. TEBD, the algorithm has several advantages:
 e.g. it conserves the unitarity of the time evolution and the energy (for the single-site version),
@@ -33,9 +33,6 @@ __all__ = ['Engine', 'H0_mixed', 'H1_mixed', 'H2_mixed']
 class Engine:
     """Time dependent variational principle 'Engine'.
 
-    You can call :meth:`run_one_site` for single-site TDVP, or
-    :meth:`run_two_sites` for two-site TDVP.
-
     .. deprecated :: 0.6.0
         Renamed parameter/attribute `TDVP_params` to :attr:`options`.
 
@@ -56,10 +53,16 @@ class Engine:
 
     .. cfg:config :: TDVP
 
+        active_sites
+            The number of active sites to be used for the time evolution.
+            If set to 1, :meth:`run_one_site` is used. The bond dimension will not increase!
+            If set to 2, :meth:`run_two_sites` is used.
         start_time : float
             Initial value for :attr:`evolved_time`
         dt : float
             Time step of the Trotter error
+        N_steps : int
+            Number of time steps `dt` to evolve.
         trunc_params : dict
             Truncation parameters as described in :func:`~tenpy.algorithms.truncation.truncate`
         Lanczos : dict
@@ -104,7 +107,17 @@ class Engine:
         warnings.warn("renamed self.TDVP_params -> self.options", FutureWarning, stacklevel=2)
         return self.options
 
-    # Actual calculation
+    def run(self):
+        """(Real-)time evolution with TDVP.
+        """
+        active_sites = self.options.get('active_sites', 2)
+        if active_sites == 1:
+            self.run_one_site(self.N_steps)
+        elif active_sites == 2:
+            self.run_two_sites(self.N_steps)
+        else:
+            raise ValueError("TDVP can only use 1 or 2 active sites, not {}".format(active_sites))
+
     def run_one_site(self, N_steps=None):
         """Run the TDVP algorithm with the one site algorithm.
 
